main_length = 170;
mount_length = 40;
thickness = 10;
height = 20;
stop_size = 15;
slope = 30;
screw_diameter = 4;
screw_head_diameter = 8;
fudge = 1;
$fn = 32;

difference() {
    union() {
        // Main body
        hull() {
            rotate(-slope) rcube([main_length + thickness, thickness, height], [0, thickness / 2, 0, 0]);
            translate([-mount_length, 0, 0]) rcube([mount_length, thickness, height], [thickness / 2, 0, 0, 0]);
        }

        // Stop
        rotate(-slope) translate([main_length, 0, 0]) rcube([thickness, thickness + stop_size, height], [0, thickness / 2, thickness / 2, thickness / 2]);
    }

    // Mounting holes
    translate([-mount_length * .3, thickness + fudge, height / 2]) rotate([90, 0, 0]) {
        cylinder(d = screw_diameter, h = main_length);
        translate([0, 0, thickness / 2 - fudge]) cylinder(d = screw_head_diameter, h = main_length);
    }
    translate([-mount_length * .7, thickness + fudge, height / 2]) rotate([90, 0, 0]) {
        cylinder(d = screw_diameter, h = main_length);
        translate([0, 0, thickness / 2 - fudge]) cylinder(d = screw_head_diameter, h = main_length);
    }
}

module rcube(size, radius) {
    if(len(radius) == undef) {
        // The same radius on all corners
        rcube(size, [radius, radius, radius, radius]);
    } else if(len(radius) == 2) {
        // Different radii on top and bottom
        rcube(size, [radius[0], radius[0], radius[1], radius[1]]);
    } else if(len(radius) == 4) {
        // Different radius on different corners
        hull() {
            // BL
            if(radius[0] == 0) cube([1, 1, size[2]]);
            else translate([radius[0], radius[0]]) cylinder(r = radius[0], h = size[2]);
            // BR
            if(radius[1] == 0) translate([size[0] - 1, 0]) cube([1, 1, size[2]]);
            else translate([size[0] - radius[1], radius[1]]) cylinder(r = radius[1], h = size[2]);
            // TR
            if(radius[2] == 0) translate([size[0] - 1, size[1] - 1])cube([1, 1, size[2]]);
            else translate([size[0] - radius[2], size[1] - radius[2]]) cylinder(r = radius[2], h = size[2]);
            // TL
            if(radius[3] == 0) translate([0, size[1] - 1]) cube([1, 1, size[2]]);
            else translate([radius[3], size[1] - radius[3]]) cylinder(r = radius[3], h = size[2]);
        }
    } else {
        echo("ERROR: Incorrect length of 'radius' parameter. Expecting integer or vector with length 2 or 4.");
    }
}